==> ldt-esm-0.0.3.tgz: package/src/LineNumbers.js <==
export function LineNumbers(API, options) {
	if (typeof document === 'object') {
		LDTLineNumbersInjectStyles();
	}
	const textarea = API.input;
	const parent = textarea.parentElement.parentElement;

	const transitionTime = options && options.transitionTime || 0;
	const padding = options && (options.padding === 0 ? 0 : options.padding || 1.5) || 1.5;
	parent.style.setProperty('--ln-digits', `${transitionTime}s`);
	parent.style.setProperty('--ln-padding', padding);

	let previous = 0
	
	parent.addEventListener("input", update, false);
	update();
	function update() {
		const lines = textarea.rows;
		if (lines !== previous) {
			previous = lines;
			const size = Math.ceil(Math.log10(lines + 1));
			const content = `'${
				Array.from({ length: lines }, (_, i) => `${i + 1}`.padStart(size, ' ')).join("\\A ")
			}'`;
			parent.style.setProperty('--ln-digits', size);
			parent.style.setProperty('--ln-transition-time', content);
		}
	}
};

let LDTLineNumberStyleInjected = false
export function LDTLineNumbersInjectStyles() {
	if (!LDTLineNumberStyleInjected) {
		LDTLineNumberStyleInjected = true;
		document.head.append(
			Object.assign(
				document.createElement('style'),
				{
					textContent: `
.ldt {
	--ln-digits: 1;
	--ln-content: "1";
	--ln-padding: 1.5;
	--ln-transition-time: 0s;
}
.ldt label {
	padding-left: 0;
}
.ldt, .ldt textarea {
	padding-left: calc((var(--ln-digits) + var(--ln-padding) * 2) * 1ch);
	transition: padding-left var(--ln-transition-time);
}

.ldt::before{
	background-color: #f6f6f6;
	box-sizing: border-box;

	color: grey;
	content: var(--ln-content);
	display: block;
	left: 0;
	padding-right: calc(var(--ln-padding) * 1ch);
	position: absolute;
	text-align: right;
	white-space: pre;
	width: calc((var(--ln-digits) + var(--ln-padding) * 2) * 1ch);
	transition: width var(--ln-transition-time);
}`}
		))
	}
};

==> ldt-esm-0.0.4.tgz: package/src/LineNumbers.js <==
export function LineNumbers(API, options) {
	if (typeof document === 'object') {
		LDTLineNumbersInjectStyles();
	}
	const textarea = API.input;
	const parent = textarea.parentElement.parentElement;

	const transitionTime = options && options.transitionTime || 0;
	const padding = options && (options.padding === 0 ? 0 : options.padding || 1.5) || 1.5;
	parent.style.setProperty('--ln-transition-time', `${transitionTime}s`);
	parent.style.setProperty('--ln-padding', padding);

	let previous = 0
	
	parent.addEventListener("input", update, false);
	update();
	function update() {
		const lines = textarea.rows;
		if (lines !== previous) {
			previous = lines;
			const size = Math.ceil(Math.log10(lines + 1));
			const content = `'${
				Array.from({ length: lines }, (_, i) => `${i + 1}`.padStart(size, ' ')).join("\\A ")
			}'`;
			parent.style.setProperty('--ln-digits', size);
			parent.style.setProperty('--ln-content', content);
		}
	}
};

let LDTLineNumberStyleInjected = false
export function LDTLineNumbersInjectStyles() {
	if (!LDTLineNumberStyleInjected) {
		LDTLineNumberStyleInjected = true;
		document.head.append(
			Object.assign(
				document.createElement('style'),
				{
					textContent: `
.ldt {
	--ln-digits: 1;
	--ln-content: "1";
	--ln-padding: 1.5;
	--ln-transition-time: 0s;
}
.ldt label {
	padding-left: 0;
}
.ldt, .ldt textarea {
	padding-left: calc((var(--ln-digits) + var(--ln-padding) * 2) * 1ch);
	transition: padding-left var(--ln-transition-time);
}

.ldt::before{
	background-color: #f6f6f6;
	box-sizing: border-box;

	color: grey;
	content: var(--ln-content);
	display: block;
	left: 0;
	padding-right: calc(var(--ln-padding) * 1ch);
	position: absolute;
	text-align: right;
	white-space: pre;
	width: calc((var(--ln-digits) + var(--ln-padding) * 2) * 1ch);
	transition: width var(--ln-transition-time);
}`}
		))
	}
};
